function [prdData, info] = predict_Eledone_cirrhosa(par, data, auxData)
  
  % unpack par, data, auxData
  cPar = parscomp_st(par); vars_pull(par); 
  vars_pull(cPar);  vars_pull(data);  vars_pull(auxData);
    
  if p_M > 1000
    info = 0; prdData = []; return
  end
  
  % compute temperature correction factors
  TC_ab = tempcorr(temp.ab, T_ref, T_A);
  TC = tempcorr(temp.am, T_ref, T_A); kT_M = k_M * TC;
  
  % zero-variate data

  
  % life cycle
  pars_tj = [g; k; l_T; v_Hb; v_Hj; v_Hp];
  [t_j, t_p, t_b, l_j, l_p, l_b, l_i, rho_j, rho_B, info] = get_tj(pars_tj, f);
  
  % birth
  L_b = L_m * l_b;                  % cm, structural length at birth at f
  Ww_b = L_b^3 * (1 + f * w);       % g, wet weight at birth
  aT_b = t_b/ k_M/ TC_ab;           % d, age at birth
  
  % metam
  L_j = L_m * l_j;                  % cm, structural length at metam
  tT_j = (t_j - t_b)/ k_M;          % d, time since birth at metam
  
  % puberty 
  L_p = L_m * l_p;                  % cm, structural length at puberty at f
  Ww_p = L_p^3 * (1 + f * w);       % g, wet weight at puberty at f

  % life span
  pars_tm = [pars_tj; h_a/ k_M^2; s_G]; % compose parameter vector at T_ref
  t_m = get_tm_j(pars_tm, f);           % -, scaled mean life span at T_ref
  aT_m = t_m/ kT_M;                     % d, mean life span at T
  
  % ultimate
  L_i = L_m * l_i; rT_B = rho_B * kT_M;  % cm, ultimate structural length at f
  L_am = L_i - (L_i - L_j) * exp(- rT_B * (aT_m  - t_j/ kT_M));  
  Ww_i = L_am^3 * (1 + f * w);     % g, wet weight at death
 
  % reproduction
  pars_R = [kap; kap_R; g; TC*k_J; kT_M; L_T; TC*v; U_Hb/TC; U_Hj/TC; U_Hp/TC]; % compose parameter vector
  NT_i = cum_reprod_j(aT_m, f, pars_R); % #, cum no of eggs

  % pack to output
  prdData.ab = aT_b;
  prdData.am = aT_m;
  prdData.Wwb = Ww_b;
  prdData.Wwp = Ww_p;
  prdData.Wwi = Ww_i;
  prdData.Ni = NT_i;
  
  % uni-variate data
  
  % time-weight.length
  [t_j, t_p, t_b, l_j, l_p, l_b, l_i, rho_j, rho_B] = get_tj(pars_tj, f_tW);
  L_b = l_b * L_m; L_j = l_j * L_m; L_i = l_i * L_m; 
  rT_j = rho_j * kT_M; rT_B = rho_B * kT_M; tT_j = (t_j - t_b)/ kT_M;
  L_bj = L_b * exp(tWw_f(tWw_f(:,1) <= tT_j,1) * rT_j/ 3); % cm, struct length
  L_jm = L_i - (L_i - L_j) * exp( - rT_B * (tWw_f(tWw_f(:,1) > tT_j,1)- tT_j)); % cm, struc length
  EWw_f = [L_bj; L_jm].^3 * (1 + f_tW * w);   % g, wet weight
  %
  L_bj = L_b * exp(tWw_m(tWw_m(:,1) <= tT_j,1) * rT_j/ 3); % cm, struct length
  L_jm = L_i - (L_i - L_j) * exp( - rT_B * (tWw_m(tWw_m(:,1) > tT_j,1)- tT_j)); % cm, struc length
  EWw_m = [L_bj; L_jm].^3 * (1 + f_tW * w);   % g, wet weight
  %
  L_bj = L_b * exp(tL_f(tL_f(:,1) <= tT_j,1) * rT_j/ 3); % cm, struct length
  L_jm = L_i - (L_i - L_j) * exp( - rT_B * (tL_f(tL_f(:,1) > tT_j,1)- tT_j)); % cm, struc length
  ELw_f = [L_bj; L_jm]/ del_M;   % g, wet weight
  %
  L_bj = L_b * exp(tL_m(tL_m(:,1) <= tT_j,1) * rT_j/ 3); % cm, struct length
  L_jm = L_i - (L_i - L_j) * exp( - rT_B * (tL_m(tL_m(:,1) > tT_j,1)- tT_j)); % cm, struc length
  ELw_m = [L_bj; L_jm]/ del_M;   % g, wet weight

  % pack to output
  prdData.tL_f = ELw_f;
  prdData.tL_m = ELw_m;
  prdData.tWw_f = EWw_f;
  prdData.tWw_m = EWw_m;

